@@ -37,7 +37,6 @@
 #include <gio/gio.h>
 
 #include "gdm-xerrors.h"
-#include "gdm-signal-handler.h"
 #include "gdm-log.h"
 #include "gdm-common.h"
 #include "gdm-xdmcp-chooser-slave.h"
@@ -69,78 +68,6 @@ get_system_bus (void)
         return bus;
 }
 
-static gboolean
-signal_cb (int      signo,
-           gpointer data)
-{
-        int ret;
-
-        g_debug ("Got callback for signal %d", signo);
-
-        ret = TRUE;
-
-        switch (signo) {
-        case SIGSEGV:
-        case SIGBUS:
-        case SIGILL:
-        case SIGABRT:
-                g_debug ("Caught signal %d.", signo);
-
-                ret = FALSE;
-                break;
-
-        case SIGFPE:
-        case SIGPIPE:
-                /* let the fatal signals interrupt us */
-                g_debug ("Caught signal %d, shutting down abnormally.", signo);
-                ret = FALSE;
-
-                break;
-
-        case SIGINT:
-        case SIGTERM:
-                /* let the fatal signals interrupt us */
-                g_debug ("Caught signal %d, shutting down normally.", signo);
-                ret = FALSE;
-
-                break;
-
-        case SIGHUP:
-                g_debug ("Got HUP signal");
-                /* FIXME:
-                 * Reread config stuff like system config files, VPN service files, etc
-                 */
-                ret = TRUE;
-
-                break;
-
-        case SIGUSR1:
-                g_debug ("Got USR1 signal");
-                /* we get this from xorg - can't use for anything else */
-                ret = TRUE;
-
-                gdm_log_toggle_debug ();
-
-                break;
-
-        case SIGUSR2:
-                g_debug ("Got USR2 signal");
-                ret = TRUE;
-
-                gdm_log_toggle_debug ();
-
-                break;
-
-        default:
-                g_debug ("Caught unhandled signal %d", signo);
-                ret = TRUE;
-
-                break;
-        }
-
-        return ret;
-}
-
 static void
 on_slave_stopped (GdmSlave   *slave,
                   GMainLoop  *main_loop)
@@ -150,6 +77,26 @@ on_slave_stopped (GdmSlave   *slave,
         g_main_loop_quit (main_loop);
 }
 
+static gboolean
+on_shutdown_signal_cb (gpointer user_data)
+{
+        GMainLoop *mainloop = user_data;
+
+        g_main_loop_quit (mainloop);
+
+        return FALSE;
+}
+
+static gboolean
+on_sigusr2_cb (gpointer user_data)
+{
+        g_debug ("Got USR2 signal");
+
+        gdm_log_toggle_debug ();
+
+        return TRUE;
+}
+
 static gboolean
 is_debug_set (void)
 {
@@ -173,7 +120,6 @@ main (int    argc,
         GDBusConnection  *connection;
         GdmSlave         *slave;
         static char      *display_id = NULL;
-        GdmSignalHandler *signal_handler;
         static GOptionEntry entries []   = {
                 { "display-id", 0, 0, G_OPTION_ARG_STRING, &display_id, N_("Display ID"), N_("ID") },
                 { NULL }
@@ -217,20 +163,9 @@ main (int    argc,
 
         main_loop = g_main_loop_new (NULL, FALSE);
 
-        signal_handler = gdm_signal_handler_new ();
-        gdm_signal_handler_set_fatal_func (signal_handler,
-                                           (GDestroyNotify)g_main_loop_quit,
-                                           main_loop);
-        gdm_signal_handler_add (signal_handler, SIGTERM, signal_cb, NULL);
-        gdm_signal_handler_add (signal_handler, SIGINT, signal_cb, NULL);
-        gdm_signal_handler_add (signal_handler, SIGILL, signal_cb, NULL);
-        gdm_signal_handler_add (signal_handler, SIGBUS, signal_cb, NULL);
-        gdm_signal_handler_add (signal_handler, SIGFPE, signal_cb, NULL);
-        gdm_signal_handler_add (signal_handler, SIGHUP, signal_cb, NULL);
-        gdm_signal_handler_add (signal_handler, SIGSEGV, signal_cb, NULL);
-        gdm_signal_handler_add (signal_handler, SIGABRT, signal_cb, NULL);
-        gdm_signal_handler_add (signal_handler, SIGUSR1, signal_cb, NULL);
-        gdm_signal_handler_add (signal_handler, SIGUSR2, signal_cb, NULL);
+        g_unix_signal_add (SIGTERM, on_shutdown_signal_cb, main_loop);
+        g_unix_signal_add (SIGINT, on_shutdown_signal_cb, main_loop);
+        g_unix_signal_add (SIGUSR2, on_sigusr2_cb, NULL);
 
         slave = gdm_xdmcp_chooser_slave_new (display_id);
         if (slave == NULL) {
@@ -248,10 +183,6 @@ main (int    argc,
                 g_object_unref (slave);
         }
 
-        if (signal_handler != NULL) {
-                g_object_unref (signal_handler);
-        }
-
         g_main_loop_unref (main_loop);
 
  out:
